[//]: # ([![PyPI - Version]&#40;https://img.shields.io/pypi/v/kronoterm-cloud-api&#41;]&#40;https://pypi.org/project/kronoterm-cloud-api/&#41;)
[//]: # ([![ruff]&#40;https://github.com/LeskoIam/kronoterm_cloud_api/actions/workflows/ruff.yml/badge.svg?branch=master&#41;]&#40;https://github.com/LeskoIam/kronoterm_cloud_api/actions/workflows/ruff.yml&#41;)

# mermaid2image

Transform your mermaid markdown to images.
